# Copyright (C) 2009  red-agent <hell.director@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
This module contains examples of how to create your own commands by creating an
adhoc command processor. Each adhoc command processor should be hosted by one or
more which dispatch the real deal and droppped in to where it belongs.
"""

from framework import command
from implementation import ChatCommands, PrivateChatCommands, GroupChatCommands

class CustomCommonCommands(ChatCommands, PrivateChatCommands, GroupChatCommands):
    """
    This adhoc processor will be hosted by a multiple processors which dispatch
    commands from all, chat, private chat and group chat. So commands defined
    here will be available to all of them.
    """

    DISPATCH = True
    HOSTED_BY = ChatCommands, PrivateChatCommands, GroupChatCommands

    @command
    def dance(self):
        """
        First line of the doc string is called a description and will be
        programmatically extracted.

        After that you can give more help, like explanation of the options. This
        one will be programatically extracted and formatted too. After this one
        there will be autogenerated (based on the method signature) usage
        information appended. You can turn it off though, if you want.
        """
        return "I can't dance, you stupid fuck, I'm just a command system! A cool one, though..."

class CustomChatCommands(ChatCommands):
    """
    This adhoc processor will be hosted by a ChatCommands processor which
    dispatches commands from a chat. So commands defined here will be available
    only to a chat.
    """

    DISPATCH = True
    HOSTED_BY = ChatCommands

    @command
    def sing(self):
        return "Are you phreaking kidding me? Buy yourself a damn stereo..."

class CustomPrivateChatCommands(PrivateChatCommands):
    """
    This adhoc processor will be hosted by a PrivateChatCommands processor which
    dispatches commands from a private chat. So commands defined here will be
    available only to a private chat.
    """

    DISPATCH = True
    HOSTED_BY = PrivateChatCommands

    @command
    def make_coffee(self):
        return "What do I look like, you ass? A coffee machine!?"

class CustomGroupChatCommands(GroupChatCommands):
    """
    This adhoc processor will be hosted by a GroupChatCommands processor which
    dispatches commands from a group chat. So commands defined here will be
    available only to a group chat.
    """

    DISPATCH = True
    HOSTED_BY = GroupChatCommands

    @command
    def fetch(self):
        return "You should really buy yourself a dog and start torturing it instead of me..."
